@@ -3,7 +3,7 @@ package WWW::Contact::Lycos;
 use Moose;
 extends 'WWW::Contact::Base';
 
-our $VERSION   = '0.15';
+our $VERSION   = '0.16';
 our $AUTHORITY = 'cpan:SACHINJSK';
 
 sub get_contacts {
@@ -95,7 +95,7 @@ get contacts from Lycos. extends L<WWW::Contact::Base>
 
 =head1 SEE ALSO
 
-L<WWW::Contact>, L<WWW::Contact::Base>, L<WWW::Mechanize::GZip>
+L<WWW::Contact>, L<WWW::Contact::Base>, L<WWW::Mechanize>
 
 =head1 AUTHOR
 
