@@ -3,7 +3,7 @@ package WWW::Contact::Rediffmail;
 use Moose;
 extends 'WWW::Contact::Base';
 
-our $VERSION   = '0.15';
+our $VERSION   = '0.16';
 our $AUTHORITY = 'cpan:SACHINJSK';
 
 sub get_contacts {
@@ -69,6 +69,7 @@ sub get_contacts_from_thunderbird_csv {
     # first_name, last_name, full_name, nickname, e-mail.
     my @lines = split(/\n/, $csv);
     foreach my $line (@lines) {
+        $line =~ s/"//g;
         my @cols = split(',', $line);
         push @contacts, {
             name  => $cols[2],
@@ -108,7 +109,7 @@ get contacts from Rediff Mail. extends L<WWW::Contact::Base>
 
 =head1 SEE ALSO
 
-L<WWW::Contact>, L<WWW::Contact::Base>, L<WWW::Mechanize::GZip>
+L<WWW::Contact>, L<WWW::Contact::Base>, L<WWW::Mechanize>
 
 =head1 AUTHOR
 
